@@ -22,6 +22,7 @@
 #include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
 #include <goffice/utils/go-marshalers.h>
+#include <goffice/gtk/go-gtk-compat.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -283,7 +284,7 @@ cb_decimals_changed (GtkSpinButton *spin, GOFormatSel *gfs)
 	gfs->format.details.num_decimals =
 		gtk_spin_button_get_value_as_int (spin);
 
-	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
+	if (gtk_widget_get_visible (gfs->format.widget[F_NEGATIVE]))
 		fillin_negative_samples (gfs);
 
 	draw_format_preview (gfs, TRUE);
@@ -295,7 +296,7 @@ cb_separator_toggle (GtkObject *obj, GOFormatSel *gfs)
 	gfs->format.details.thousands_sep =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (obj));
 
-	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
+	if (gtk_widget_get_visible (gfs->format.widget[F_NEGATIVE]))
 		fillin_negative_samples (gfs);
 
 	draw_format_preview (gfs, TRUE);
@@ -381,6 +382,11 @@ find_builtin (const char *fmtstr, int page, gboolean def)
 		list_elem++;
 	}
 
+	if (candidates[list_elem] == NULL &&
+	    page == GO_FORMAT_GENERAL &&
+	    g_ascii_strcasecmp (candidates[0], fmtstr) == 0)
+		list_elem = 0; /* "GENERAL" */
+
 	if (candidates[list_elem] == NULL && def)
 		list_elem = 0;
 
@@ -641,11 +647,12 @@ stays:
 		}
 
 		if (show_widget) {
-			while (!GTK_WIDGET_VISIBLE (w)) {
+			while (!gtk_widget_get_visible (w)) {
 				gtk_widget_show (w);
-				w = w->parent;
+				w = gtk_widget_get_parent (w);
 			}
 		}
+
 	}
 
 	draw_format_preview (gfs, TRUE);
@@ -758,7 +765,7 @@ cb_format_currency_select (G_GNUC_UNUSED GtkWidget *ct,
 		}
 	}
 
-	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
+	if (gtk_widget_get_visible (gfs->format.widget[F_NEGATIVE]))
 		fillin_negative_samples (gfs);
 
 	draw_format_preview (gfs, TRUE);
@@ -799,7 +806,7 @@ funny_currency_order (gconstpointer _a, gconstpointer _b)
 
 	if (a1) {
 		if (b1) {
-			return strcmp (a, b);
+			return g_utf8_collate (a, b);
 		} else {
 			return -1;
 		}
@@ -807,7 +814,7 @@ funny_currency_order (gconstpointer _a, gconstpointer _b)
 		if (b1) {
 			return +1;
 		} else {
-			return strcmp (a, b);
+			return g_utf8_collate (a, b);
 		}
 	}
 }
